@@ -1,6 +1,6 @@
 var group__pw__keys =
 [
-    [ "keys.h", "src_2pipewire_2keys_8h.html", null ],
+    [ "src/pipewire/keys.h", "src_2pipewire_2keys_8h.html", null ],
     [ "PW_KEY_PROTOCOL", "group__pw__keys.html#ga75a6c78ce2de6d3dc5ed23abecdbc3bd", null ],
     [ "PW_KEY_ACCESS", "group__pw__keys.html#gad1bfca30c613b28723527132429bb342", null ],
     [ "PW_KEY_CLIENT_ACCESS", "group__pw__keys.html#ga550a0954601e7bf139955115f4b1c030", null ],
@@ -59,7 +59,6 @@ var group__pw__keys =
     [ "PW_KEY_NODE_GROUP", "group__pw__keys.html#ga5b8ea75d1a6f9a1d0d0e60e60eeae5a8", null ],
     [ "PW_KEY_NODE_EXCLUSIVE", "group__pw__keys.html#gacc9bbcbe9fc948df2fec4592640cd39c", null ],
     [ "PW_KEY_NODE_AUTOCONNECT", "group__pw__keys.html#ga677b0938b4f1d2d52326c64b4b90eb8e", null ],
-    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ],
     [ "PW_KEY_NODE_LATENCY", "group__pw__keys.html#ga6d08c36bb4d3bcae49e822023a8089e2", null ],
     [ "PW_KEY_NODE_MAX_LATENCY", "group__pw__keys.html#gaad5f9ff2318f5ff7156b81e4efa4b9fc", null ],
     [ "PW_KEY_NODE_LOCK_QUANTUM", "group__pw__keys.html#ga7e12dd6c9dec4a345c8a2a62f138b5bf", null ],
@@ -81,6 +80,8 @@ var group__pw__keys =
     [ "PW_KEY_NODE_LINK_GROUP", "group__pw__keys.html#ga30bf1394ef6129573c44fea7d3af880e", null ],
     [ "PW_KEY_NODE_NETWORK", "group__pw__keys.html#ga7cc45df5bd241b9bb924802082490449", null ],
     [ "PW_KEY_NODE_TRIGGER", "group__pw__keys.html#ga0346a35752b5d7641d7cd7b146733abf", null ],
+    [ "PW_KEY_NODE_CHANNELNAMES", "group__pw__keys.html#ga6e00a9edf0a824959dd276c74091e48f", null ],
+    [ "PW_KEY_NODE_DEVICE_PORT_NAME_PREFIX", "group__pw__keys.html#ga5545c435aac2f053d2b4d5f59510818d", null ],
     [ "PW_KEY_PORT_ID", "group__pw__keys.html#ga94975808271e28be225a6fd6d7957762", null ],
     [ "PW_KEY_PORT_NAME", "group__pw__keys.html#ga086fc9bb9864325037b0bd2310816034", null ],
     [ "PW_KEY_PORT_DIRECTION", "group__pw__keys.html#ga4a25213dfcf1d7b7ded06ed9284f1a5f", null ],
@@ -162,5 +163,7 @@ var group__pw__keys =
     [ "PW_KEY_VIDEO_RATE", "group__pw__keys.html#gac353c9d9c3ed50ea98806f63f09f9456", null ],
     [ "PW_KEY_VIDEO_FORMAT", "group__pw__keys.html#ga38e8da2c19e9cd1acf5823865f6e9742", null ],
     [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ],
-    [ "PW_KEY_TARGET_OBJECT", "group__pw__keys.html#ga7983296afaca4d7edac60714fa92565b", null ]
+    [ "PW_KEY_TARGET_OBJECT", "group__pw__keys.html#ga7983296afaca4d7edac60714fa92565b", null ],
+    [ "PW_KEY_PRIORITY_MASTER", "group__pw__keys.html#ga1872a5fd956b36a36793554d22d99c6c", null ],
+    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ]
 ];
\ No newline at end of file
