@@ -1,17 +1,13 @@
 var group__spa__types =
 [
-    [ "type-info.h", "utils_2type-info_8h.html", null ],
-    [ "type.h", "spa_2include_2spa_2utils_2type_8h.html", null ],
+    [ "utils/type-info.h", "utils_2type-info_8h.html", null ],
+    [ "spa/include/spa/utils/type.h", "spa_2include_2spa_2utils_2type_8h.html", null ],
     [ "spa_type_info", "structspa__type__info.html", [
       [ "type", "structspa__type__info.html#a25dfe56fe53d756509cd5daa5f5b64e5", null ],
       [ "parent", "structspa__type__info.html#ab94f9983f18d62536d03ba5eb7db9bae", null ],
       [ "values", "structspa__type__info.html#afedc2465e18bf4d93bf2a3d8afcc4c13", null ]
     ] ],
     [ "SPA_TYPE_ROOT", "group__spa__types.html#gafbabcef02a8226b94cd9708d0e3bda6c", null ],
-    [ "SPA_TYPE_INFO_Direction", "group__spa__types.html#gaaca7a372068124b38f09b0bd2fef0f98", null ],
-    [ "SPA_TYPE_INFO_DIRECTION_BASE", "group__spa__types.html#gab8f02181d37e1c034e04797628a8ee1b", null ],
-    [ "SPA_TYPE_INFO_Choice", "group__spa__types.html#gaaaa70c8c33c359627dd29efe58e62503", null ],
-    [ "SPA_TYPE_INFO_CHOICE_BASE", "group__spa__types.html#ga21cc1e946168521828401b4b652c3318", null ],
     [ "SPA_TYPE_INFO_BASE", "group__spa__types.html#ga12e7f34d2ebf7bb4ad1b14997148383f", null ],
     [ "SPA_TYPE_INFO_Flags", "group__spa__types.html#ga886514f37da7215fa5eebe406e2f3b37", null ],
     [ "SPA_TYPE_INFO_FLAGS_BASE", "group__spa__types.html#gad9c69f01ba4f4907c8550164be6d3d49", null ],
@@ -84,7 +80,5 @@ var group__spa__types =
       [ "SPA_TYPE_VENDOR_Other", "group__spa__types.html#ggab04a0655cd1e3bcac5e8f48c18df1a57a3b923c5f09c56b563d4d5bf4ab2a4cb0", null ]
     ] ],
     [ "spa_type_is_a", "group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3", null ],
-    [ "spa_type_direction", "group__spa__types.html#gafff747a1e17cacd06f036b94ad100aaa", null ],
-    [ "spa_type_choice", "group__spa__types.html#ga3f8207af24a34e29769be91b720c5191", null ],
     [ "spa_types", "group__spa__types.html#gafb8bf694625474ebfb1ecdce28bb4828", null ]
 ];
\ No newline at end of file
