@@ -2,7 +2,7 @@ var indexSectionsWithContent =
 {
   0: "_abcdefghijklmnopqrstuvwxyz",
   1: "ips",
-  2: "abcdefghijklmnprstuvw",
+  2: "abcdfghijlmnprstuvw",
   3: "_ps",
   4: "_abcdefghijklmnopqrstuvwxyz",
   5: "ps",
